const jwt = require('jsonwebtoken');

class WorkerBridge {
    constructor(secret) {
        this.secret = secret;
    }

    /**
     * Creates a one time token to access the workers api
     * @param {JSON} body 
     * @param {Number} duration
     * @async
     * @returns Promise<String>
     */
    async signTaskId(body, duration) {
        return jwt.sign({data: body}, this.secret, {
            expiresIn: (duration === undefined) ? '10m': duration
        });
    }

    /**
     * Validates the provided token
     * @param {*} token 
     * @async
     * @returns Promise<any>
     */
    async validateTaskId(token) {
        return new Promise((resolve, reject) => {
            jwt.verify(token, this.secret, (error, decode) => {
                if(error) {
                    if(error.name == 'JsonWebTokenError' && error.message == 'invalid signature') throw new Error('The provided secret does not match with the provided token')
                    if(error.name == 'TokenExpiredError' && error.message == 'jwt expired') throw new Error('The provided token has been expired change the duration of the token')

                    return reject('Invalid Token');
                }
                else return resolve(decode.data);
            })
        })
    }
}

module.exports = WorkerBridge;